@@ -1,6 +1,6 @@
 from typing import List, Union
 
-from mcqa_utils.metric import Metric, metrics_result_prefixes
+from mcqa_utils.metric import Metric
 from mcqa_utils.answer import Answer
 
 
@@ -28,9 +28,9 @@ class GenericEvaluator(Evaluator):
     ) -> float:
         results = {}
         for metric in self.metrics:
-            value, stats = metric(gold_answers, answers)
-            prefs = metrics_result_prefixes[:len(stats)]
-            results[metric.name] = value
-            for stat, prefix in zip(stats, prefs):
-                results[f'{metric.name}_{prefix}'] = stat
+            metric_output = metric(gold_answers, answers)
+            results[metric.name] = metric_output.value
+            for key, value in vars(metric_output).items():
+                if key != "value" and value is not None:
+                    results[f'{metric.name}_{key}'] = value
         return results
